==> mono-1.1.7.tar.gz: mono-1.1.7/mcs/class/System/System.Net.Configuration/NetSectionGroup.cs <==
//
// System.Net.Configuration.NetSectionGroup.cs
//
// Authors:
//	Tim Coleman (tim@timcoleman.com)
//
// Copyright (C) Tim Coleman, 2004
// (c) 2004 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && XML_DEP

using System.Configuration;

namespace System.Net.Configuration 
{
	public sealed class NetSectionGroup : ConfigurationSectionGroup
	{
		#region Constructors

		[MonoTODO]
		public NetSectionGroup ()
		{
		}

		#endregion // Constructors

		#region Properties

		[MonoTODO]
		public AuthenticationModulesSection AuthenticationModules {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public ConnectionManagementSection ConnectionManagement {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public DefaultProxySection DefaultProxy {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public MailSettingsSection MailSettings {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public RequestCachingSection RequestCaching {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public SettingsSection Settings {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public UriParserSection UriParser {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public WebRequestModulesSection WebRequestModules {
			get { throw new NotImplementedException (); }
		}

		#endregion // Properties

		#region Methods

		[MonoTODO]
		public static NetSectionGroup GetSectionGroup (System.Configuration.Configuration config)
		{
			throw new NotImplementedException ();
		}

		#endregion // Methods
	}
}

#endif

==> mono-1.1.9.2.tar.gz: mono-1.1.9.2/mcs/class/System/System.Net.Configuration/NetSectionGroup.cs <==
//
// System.Net.Configuration.NetSectionGroup.cs
//
// Authors:
//	Tim Coleman (tim@timcoleman.com)
//
// Copyright (C) Tim Coleman, 2004
// (c) 2004 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && CONFIGURATION_DEP

using System.Configuration;

namespace System.Net.Configuration 
{
	public sealed class NetSectionGroup : ConfigurationSectionGroup
	{
		#region Constructors

		[MonoTODO]
		public NetSectionGroup ()
		{
		}

		#endregion // Constructors

		#region Properties

		[MonoTODO]
		public AuthenticationModulesSection AuthenticationModules {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public ConnectionManagementSection ConnectionManagement {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public DefaultProxySection DefaultProxy {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public MailSettingsSection MailSettings {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public RequestCachingSection RequestCaching {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public SettingsSection Settings {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public UriParserSection UriParser {
			get { throw new NotImplementedException (); }
		}

		[MonoTODO]
		public WebRequestModulesSection WebRequestModules {
			get { throw new NotImplementedException (); }
		}

		#endregion // Properties

		#region Methods

		[MonoTODO]
		public static NetSectionGroup GetSectionGroup (System.Configuration.Configuration config)
		{
			throw new NotImplementedException ();
		}

		#endregion // Methods
	}
}

#endif
